## 期货日线行情

接口：fut_daily，可以通过数据工具调试和查看数据。

描述：期货日线行情数据

限量：单次最大2000条，总量不限制

积分：用户需要至少2000积分才可以调取，未来可能调整积分，请尽量多的积累积分。具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | N | 交易日期(YYYYMMDD格式，下同) |
| ts_code | str | N | 合约代码 |
| exchange | str | N | 交易所代码 |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y | TS合约代码 |
| trade_date | str | Y | 交易日期 |
| pre_close | float | Y | 昨收盘价 |
| pre_settle | float | Y | 昨结算价 |
| open | float | Y | 开盘价 |
| high | float | Y | 最高价 |
| low | float | Y | 最低价 |
| close | float | Y | 收盘价 |
| settle | float | Y | 结算价 |
| change1 | float | Y | 涨跌1 收盘价-昨结算价 |
| change2 | float | Y | 涨跌2 结算价-昨结算价 |
| vol | float | Y | 成交量(手) |
| amount | float | Y | 成交金额(万元) |
| oi | float | Y | 持仓量(手) |
| oi_chg | float | Y | 持仓量变化 |
| delv_settle | float | N | 交割结算价 |

接口示例

```python
pro = ts.pro_api()

#获取CU1811合约20180101～20181113期间的行情
df = pro.fut_daily(ts_code='CU1811.SHF', start_date='20180101', end_date='20181113')

#获取2018年11月13日大商所全部合约行情数据
df = pro.fut_daily(trade_date='20181113', exchange='DCE', fields='ts_code,trade_date,pre_close,pre_settle,open,high,low,close,settle,vol')
```

数据示例

```python
ts_code    trade_date  pre_close  pre_settle     open     high      low  \
0    CU1811.SHF   20181113    48900.0     49030.0  48910.0  49040.0  48700.0   
```